// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "CubeMeshComponent.hpp"
#include "display/mesh/CubeMesh.hpp"
#include "util/JSON.hpp"

using namespace Dawn;

void CubeMeshComponent::meshBuffer(std::shared_ptr<Mesh> mesh) {
  mesh->createBuffers(CUBE_VERTICE_COUNT, CUBE_INDICE_COUNT);
  CubeMesh::buffer(
    mesh,
    -(size/2.0f),
    size,
    0, 0
  );
}

void CubeMeshComponent::meshLoad(std::shared_ptr<SceneLoadContext> ctx) {
  if(ctx->data.contains("size")) {
    this->size = JSON::vec3(ctx->data["size"]);
  } else {
    this->size = glm::vec3(1.0f, 1.0f, 1.0f);
  }
}

void CubeMeshComponent::setSize(const glm::vec3 &size) {
  this->size = size;
  this->invalidate();
}