// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "MeshComponent.hpp"
#include "scene/Scene.hpp"
#include "component/display/MeshRenderer.hpp"

using namespace Dawn;

void MeshComponent::buffer() {
  if(!mesh) mesh = std::make_shared<Mesh>();
  this->meshBuffer(mesh);
  this->valid = true;
  events.clear();
}

void MeshComponent::invalidate() {
  if(!valid) return;
  valid = false;
  events.push_back(getScene()->onNextFrame.listen([this]() {
    this->buffer();
    valid = true;
  }));
}

void MeshComponent::onInit() {
  this->buffer();
  auto renderer = getItem()->getComponent<MeshRenderer>();
  if(renderer) renderer->mesh = mesh;
}

void MeshComponent::onDispose() {
  mesh = nullptr;
}

void MeshComponent::load(std::shared_ptr<SceneLoadContext> ctx) {
  SceneComponent::load(ctx);
  if(this->mesh == nullptr) this->mesh = std::make_shared<Mesh>();
  this->meshLoad(ctx);
}