// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "Tileset.hpp"

namespace Dawn {
  struct TilesetGrid : public Tileset{
    public:
      int32_t rows;
      int32_t columns;
      
      /**
       * Creates a new TilesetGrid. A precalculated set of tiles that can be
       * precalculated to make getting the index and uvs of a tile easier. This
       * tileset is aligned to a simple grid (unlike a more complex UV unwrap).
       * 
       * @param columns The number of columns in the grid.
       * @param rows The number of rows in the grid.
       * @param width The width of the grid.
       * @param height The height of the grid.
       * @param gapX The gap between each column.
       * @param gapY The gap between each row.
       * @param borderX The border on the left and right of the grid.
       * @param borderY The border on the top and bottom of the grid.
       */
      TilesetGrid(
        const int32_t columns,
        const int32_t rows,
        const int32_t width,
        const int32_t height,
        const int32_t gapX = 0,
        const int32_t gapY = 0,
        const int32_t borderX = 0,
        const int32_t borderY = 0
      );

      /**
       * Gets the tile at the specified row and column.
       * 
       * @param col The column of the tile.
       * @param row The row of the tile.
       * @return The tile.
       */
      glm::vec4 getTile(const int32_t col, const int32_t row);
  };
}