// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawn.hpp"

namespace Dawn {
  class Game;
  
  class SettingsManager final {
    private:
      std::weak_ptr<Game> game;
    
    public:
      /**
       * Initializes the SettingsManager with the Game instance.
       * 
       * @param game The Game instance.
       */
      void init(const std::shared_ptr<Game> game);
      
      /**
       * Gets the Game instance.
       * 
       * @return The Game instance.
       */
      std::shared_ptr<Game> getGame();

      /**
       * Loads the settings from the settings file.
       */
      void load();

      /**
       * Saves the settings to the settings file.
       */
      void save();
  };
}