// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "event/CustomEvent.hpp"

namespace Dawn {
  struct IntervalEventData {
    float_t interval;
    float_t nextInvoke;
  };

  class IntervalEvent : public CustomEvent<
    float_t, struct IntervalEventData, float_t
  > {
    protected:
      enum CustomEventResult shouldEmit(
        const struct IntervalEventData &listener
      ) override;
      struct IntervalEventData transformData(const float_t &interval) override;
      struct IntervalEventData transformDataAfterEmit(
        const struct IntervalEventData &listenerData
      ) override;
    
    public:
      IntervalEvent();

      /**
       * Ticks this interval event by a time delta amount. Will also emit all
       * events that are ready to be emitted.
       * 
       * @param delta Delta time.
       */
      void tick(const float_t delta);
  };
}