// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "assert/assert.hpp"
#include "UIColumnContainer.hpp"

using namespace Dawn;

void UIColumnContainer::updateAlignment(
  const glm::vec2 parentPosition,
  const glm::vec2 parentSize,
  const float_t canvasScale
) {
  this->updateSelfAlignment(parentPosition, parentSize, canvasScale);

  // Now we have our dimensions, divide evenly
  auto children = this->getChildren();

  float_t x = 0.0f;
  float_t xPiece = this->size.x / (float_t)children.size();
  
  // Update all children
  for(auto &child : children) {
    child->updateAlignment(
      this->position + glm::vec2(x, 0),
      glm::vec2(
        xPiece,
        this->size.y
      ),
      canvasScale
    );
    x += xPiece;
  }
}