// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawn.hpp"
#include "display/Color.hpp"

namespace Dawn {
  class JSON final {
    public:
      /**
       * Parses the given JSON string as a vec2.
       * 
       * @param j JSON obj to parse.
       * @return Parsed vec2.
       */
      static glm::vec2 vec2(const json &j);

      /**
       * Parses the given JSON string as a vec3.
       * 
       * @param j JSON obj to parse.
       * @return Parsed vec3.
       */
      static glm::vec3 vec3(const json &j);

      /**
       * Parses the given JSON string as a vec4.
       * 
       * @param j JSON obj to parse.
       * @return Parsed vec4.
       */
      static glm::vec4 vec4(const json &j);

      /**
       * Parses the given JSON string as a color.
       * 
       * @param j JSON obj to parse.
       * @return Parsed color.
       */
      static struct Color color(const json &j);

      /**
       * Merges all objects in the given JSON object into the first object, 
       * recursively.
       * 
       * e.g. if; &a is { a: { b: 1, c: 2 }, d: 3 }
       *          &b is { a: { b: 4, d: 5 }, e: 4 }
       * 
       * The output will become;
       *   { a: { b: 4, c: 2, d: 5 }, e: 4 }
       * 
       * @param a JSON object to merge into.
       * @param b JSON object to merge from.
       */
      static void mergeObjectsRecursive(json &a, const json &b);
  };
}