// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "MapMaterial.hpp"
#include "util/JSON.hpp"
#include "asset/loader/TextureLoader.hpp"

using namespace Dawn;

void MapMaterial::load(std::shared_ptr<SceneLoadContext> ctx) {
  if(ctx->data.contains("color")) {
    this->setColor(JSON::color(ctx->data["color"]));
  }

  if(ctx->data.contains("texture")) {
    auto asset = ctx->getAsset<TextureLoader>(
      ctx->data["texture"].get<std::string>()
    );
    this->setTexture(asset->getTexture());
  }
}

struct Color MapMaterial::getColor() {
  return this->data.color;
}

std::shared_ptr<Texture> MapMaterial::getTexture() {
  return this->texture;
}

void MapMaterial::setTexture(
  const std::shared_ptr<Texture> texture
) {
  this->texture = texture;
}

void MapMaterial::setColor(const struct Color color) {
  this->data.color = color;
}

std::vector<std::shared_ptr<IRenderPass>> MapMaterial::getPasses(
  struct RenderPassContext &ctx
) {
  this->data.model = this->getItem()->getWorldTransform();
  this->data.projection = ctx.camera->getProjection();
  this->data.view = ctx.camera->getItem()->getWorldTransform();
  auto textures = std::unordered_map<
    shadertexturebinding_t, std::shared_ptr<Texture>
  >();
  
  if(this->texture) {
    this->data.hasTexture = true;
    this->data.texture = 0;
    textures[this->data.texture] = this->texture;
  } else {
    this->data.hasTexture = false;
  }

  return {
    createRenderPass<MapShader, struct MapShaderData>(
      *this,
      data,
      textures
    )
  };
}
